@@ -13,11 +13,15 @@ def main():
     out_path = sys.argv[2]
 
     if len(sys.argv) >= 4:
-        tag_parser_requested = sys.argv[3].lower()
+        tag_parser_requested = sys.argv[3].lower().replace('-', '_')
 
         tag_parser_builders = {
             'ruby':     rubysubs.tag_parse_ruby.parser_from_string_args,
             'ja':       rubysubs.tag_parse_migaku_ja.parser_from_string_args,
+            'zh':       rubysubs.tag_parse_migaku_zh.parser_from_string_args,
+            'zh_hk':    rubysubs.tag_parse_migaku_zh.parser_from_string_args_HK,
+            'eu':       rubysubs.tag_parse_migaku_eu.parser_from_string_args,
+            'ko':       rubysubs.tag_parse_migaku_ko.parser_from_string_args,
         }
 
         if not tag_parser_requested in tag_parser_builders:
